@@ -32,13 +32,15 @@ important global variables.
 
 package Coro;
 
-no warnings qw(uninitialized);
+BEGIN { eval { require warnings } && warnings->unimport ("uninitialized") }
 
 use Coro::State;
 
+use vars qw($idle $main $current);
+
 use base Exporter;
 
-$VERSION = 0.652;
+$VERSION = 0.8;
 
 @EXPORT = qw(async cede schedule terminate current);
 %EXPORT_TAGS = (
@@ -85,7 +87,7 @@ This coroutine represents the main program.
 
 =cut
 
-our $main = new Coro;
+$main = new Coro;
 
 =item $current (or as function: current)
 
@@ -98,7 +100,7 @@ if ($current) {
    $main->{specific} = $current->{specific};
 }
 
-our $current = $main;
+$current = $main;
 
 sub current() { $current }
 
@@ -110,7 +112,7 @@ implementation prints "FATAL: deadlock detected" and exits.
 =cut
 
 # should be done using priorities :(
-our $idle = new Coro sub {
+$idle = new Coro sub {
    print STDERR "FATAL: deadlock detected\n";
    exit(51);
 };
@@ -269,7 +271,7 @@ sub join {
 
 Sets (or gets, if the argument is missing) the priority of the
 process. Higher priority processes get run before lower priority
-processes. Priorities are smalled signed integer (currently -4 .. +3),
+processes. Priorities are small signed integers (currently -4 .. +3),
 that you can refer to using PRIO_xxx constants (use the import tag :prio
 to get then):
 
@@ -327,17 +329,19 @@ sub desc {
 
 =head1 BUGS/LIMITATIONS
 
- - you must make very sure that no coro is still active on global destruction.
-   very bad things might happen otherwise (usually segfaults).
- - this module is not thread-safe. You should only ever use this module from
-   the same thread (this requirement might be loosened in the future to
-   allow per-thread schedulers, but Coro::State does not yet allow this).
+ - you must make very sure that no coro is still active on global
+   destruction. very bad things might happen otherwise (usually segfaults).
+
+ - this module is not thread-safe. You should only ever use this module
+   from the same thread (this requirement might be losened in the future
+   to allow per-thread schedulers, but Coro::State does not yet allow
+   this).
 
 =head1 SEE ALSO
 
 L<Coro::Channel>, L<Coro::Cont>, L<Coro::Specific>, L<Coro::Semaphore>,
-L<Coro::Signal>, L<Coro::State>, L<Coro::Event>, L<Coro::RWLock>,
-L<Coro::Handle>, L<Coro::Socket>.
+L<Coro::Signal>, L<Coro::State>, L<Coro::Timer>, L<Coro::Event>,
+L<Coro::L<Coro::RWLock>, Handle>, L<Coro::Socket>.
 
 =head1 AUTHOR
 
