@@ -33,11 +33,11 @@ and decrement the count when resources are removed.
 
 package Coro::Semaphore;
 
-no warnings qw(uninitialized);
+BEGIN { eval { require warnings } && warnings->unimport ("uninitialized") }
 
 use Coro ();
 
-$VERSION = 0.652;
+$VERSION = 0.8;
 
 =item new [inital count]
 
