@@ -27,11 +27,11 @@ waking up all waiters.
 
 package Coro::Signal;
 
-no warnings qw(uninitialized);
+BEGIN { eval { require warnings } && warnings->unimport ("uninitialized") }
 
 use Coro ();
 
-$VERSION = 0.652;
+$VERSION = 0.8;
 
 =item $s = new Coro::Signal;
 
