@@ -24,9 +24,9 @@ when no coroutines are used).
 
 package Coro::Specific;
 
-no warnings qw(uninitialized);
+BEGIN { eval { require warnings } && warnings->unimport ("uninitialized") }
 
-$VERSION = 0.652;
+$VERSION = 0.8;
 
 =item new
 
